@@ -1,7 +1,7 @@
 {-# LANGUAGE PatternSynonyms #-}
 
 {- |
-   Copyright  : Copyright (C) 2006-2015 Bjorn Buckwalter
+   Copyright  : Copyright (C) 2006-2018 Bjorn Buckwalter
    License    : BSD3
 
    Maintainer : bjorn@buckwalter.se
@@ -17,20 +17,18 @@ provided by this package, as new features using them are still being developed.
 module Numeric.Units.Dimensional.UnitNames
 (
   -- * Data Types
-  UnitName, NameAtom, PrefixName, Metricality(..),
+  UnitName, NameAtom, Prefix, PrefixName, Metricality(..),
   -- * Construction of Unit Names
   atom, applyPrefix, (*), (/), (^), product, reduce, grouped,
   -- * Standard Names
-  baseUnitName,
-  -- ** Names for the Base Units
-  nOne, nMeter, nGram, nKilogram, nSecond, nAmpere, nKelvin, nMole, nCandela,
-  -- ** Names for the SI Metric Prefixes
-  deka, hecto, kilo, mega, giga, tera, peta, exa, zetta, yotta,
-  deci, centi, milli, micro, nano, pico, femto, atto, zepto, yocto,
+  baseUnitName, siPrefixes, nOne,
+  -- * Inspecting Prefixes
+  prefixName, scaleFactor,
   -- * Convenience Type Synonyms for Unit Name Transformations
   UnitNameTransformer, UnitNameTransformer2,
   -- * Forgetting Unwanted Phantom Types
-  weaken, strengthen, relax
+  weaken, strengthen, relax,
+  name_en, abbreviation_en, asAtomic
 )
 where
 
